@@ -21,26 +21,24 @@
 
 #include "gui/mdwslider.h"
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kiconloader.h>
 #include <kconfig.h>
-#include <kaction.h>
-#include <kmenu.h>
 #include <kglobalaccel.h>
-#include <kdebug.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
 
-#include <qicon.h>
+#include <QIcon>
 #include <qtoolbutton.h>
 #include <QObject>
 #include <qcursor.h>
 #include <QCheckBox>
+#include <QMenu>
 #include <QMouseEvent>
 #include <QLabel>
 #include <qpixmap.h>
-//#include <qwmatrix.h>
 #include <QBoxLayout>
+#include <QAction>
 
 #include "core/ControlManager.h"
 #include "core/mixer.h"
@@ -103,7 +101,7 @@ void MDWSlider::createActions()
     taction->setText( i18n("&Split Channels") );
     connect( taction, SIGNAL(triggered(bool)), SLOT(toggleStereoLinked()) );
 
-//    KAction *action;
+//    QAction *action;
 //    if ( ! m_mixdevice->mixer()->isDynamic() ) {
 //        action = _mdwActions->add<KToggleAction>( "hide" );
 //        action->setText( i18n("&Hide") );
@@ -124,7 +122,7 @@ void MDWSlider::createActions()
     }
 
     if( m_mixdevice->isMovable() ) {
-        m_moveMenu = new KMenu( i18n("Mo&ve"), this);
+        m_moveMenu = new QMenu( i18n("Mo&ve"), this);
         connect( m_moveMenu, SIGNAL(aboutToShow()), SLOT(showMoveMenu()) );
     }
 
@@ -147,12 +145,7 @@ void MDWSlider::addGlobalShortcut(QAction* qaction, const QString& label, bool d
 		//     #endif
 		//   b->enableGlobalShortcut();
 		// enableGlobalShortcut() is not there => use workaround
-#ifdef X_KMIX_KF5_BUILD
-		KGlobalAccel::setGlobalShortcut(qaction, dummyShortcut);
-#else
-		KAction* kaction = (KAction*)qaction;
-		kaction->setGlobalShortcut(dummyShortcut);
-#endif
+		KGlobalAccel::setGlobalShortcut(qaction, QKeySequence());
 	}
 }
 
@@ -165,11 +158,7 @@ void MDWSlider::createShortcutActions()
         I work around this by using a text with setText() that is unique, but still readable to the user.
     */
     QString actionSuffix  = QString(" - %1, %2").arg( mixDevice()->readableName() ).arg( mixDevice()->mixer()->readableName() );
-#ifdef X_KMIX_KF5_BUILD
     QAction *bi, *bd, *bm;
-#else
-    KAction *bi, *bd, *bm;
-#endif
 
     // -1- INCREASE VOLUME SHORTCUT -----------------------------------------
     bi = _mdwPopupActions->addAction( QString("Increase volume %1").arg( actionSuffix ) );
@@ -585,7 +574,7 @@ void MDWSlider::addSliders( QBoxLayout *volLayout, char type, Volume& vol,
 
 	foreach (VolumeChannel vc, vols )
 	{
-		//kDebug(67100) << "Add label to " << vc.chid << ": " <<  Volume::ChannelNameReadable[vc.chid];
+		//qCDebug(KMIX_LOG) << "Add label to " << vc.chid << ": " <<  Volume::ChannelNameReadable[vc.chid];
 		QWidget *subcontrolLabel;
 
 		QString subcontrolTranslation;
@@ -752,7 +741,7 @@ void MDWSlider::setIcon( QString filename, QWidget* label )
 	}
 	else
 	{
-		kError(67100) << "Pixmap missing. filename=" << filename << endl;
+		qCCritical(KMIX_LOG) << "Pixmap missing. filename=" << filename;
 	}
 }
 
@@ -914,7 +903,7 @@ void MDWSlider::volumeChange( int )
 {
 //  if ( mixDevice()->id() == "Headphone:0" )
 //  {
-//    kDebug(67100) << "headphone bug";
+//    qCDebug(KMIX_LOG) << "headphone bug";
 //  }
 	if (!m_slidersPlayback.isEmpty())
 	{
@@ -957,7 +946,7 @@ void MDWSlider::volumeChangeInternal(Volume& vol, QList<QAbstractSlider *>& ref_
 
 /**
    This slot is called, when a user has clicked the recsrc button. Also it is called by any other
-    associated KAction like the context menu.
+    associated QAction like the context menu.
  */
 void MDWSlider::toggleRecsrc()
 {
@@ -976,7 +965,7 @@ void MDWSlider::setRecsrc(bool value )
 
 /**
    This slot is called, when a user has clicked the mute button. Also it is called by any other
-    associated KAction like the context menu.
+    associated QAction like the context menu.
  */
 void MDWSlider::toggleMuted()
 {
@@ -1030,10 +1019,10 @@ void MDWSlider::increaseOrDecreaseVolume(bool decrease, Volume::VolumeTypeFlag v
 	m_mixdevice->increaseOrDecreaseVolume(decrease, volumeType);
 	// I should possibly not block, as the changes that come back from the Soundcard
 	//      will be ignored (e.g. because of capture groups)
-// 	kDebug() << "MDWSlider is blocking signals for " << m_view->id();
+// 	qCDebug(KMIX_LOG) << "MDWSlider is blocking signals for " << m_view->id();
 // 	bool oldViewBlockSignalState = m_view->blockSignals(true);
 	m_mixdevice->mixer()->commitVolumeChange(m_mixdevice);
-// 	kDebug() << "MDWSlider is unblocking signals for " << m_view->id();
+// 	qCDebug(KMIX_LOG) << "MDWSlider is unblocking signals for " << m_view->id();
 // 	m_view->blockSignals(oldViewBlockSignalState);
 }
 
@@ -1053,7 +1042,7 @@ void MDWSlider::moveStream(QString destId)
 void MDWSlider::update()
 {
 //	  bool debugMe = (mixDevice()->id() == "PCM:0" );
-//	  if (debugMe) kDebug() << "The update() PCM:0 playback state" << mixDevice()->isMuted()
+//	  if (debugMe) qCDebug(KMIX_LOG) << "The update() PCM:0 playback state" << mixDevice()->isMuted()
 //	    << ", vol=" << mixDevice()->playbackVolume().getAvgVolumePercent(Volume::MALL);
 
 	if ( m_slidersPlayback.count() != 0 || m_mixdevice->hasMuteSwitch() )
@@ -1083,7 +1072,7 @@ void MDWSlider::updateInternal(Volume& vol, QList<QAbstractSlider *>& ref_slider
 //  	  bool debugMe = (mixDevice()->id() == "PCM:0" );
 //	  if (debugMe)
 //	  {
-//	    kDebug() << "The updateInternal() PCM:0 playback state" << mixDevice()->isMuted()
+//	    qCDebug(KMIX_LOG) << "The updateInternal() PCM:0 playback state" << mixDevice()->isMuted()
 //	    << ", vol=" << mixDevice()->playbackVolume().getAvgVolumePercent(Volume::MALL);
 //	  }
   
@@ -1150,12 +1139,12 @@ void MDWSlider::updateAccesability()
         } else {
                 QList<VolumeChannel> vols = m_mixdevice->playbackVolume().getVolumes().values();
                 foreach (QAbstractSlider *slider, m_slidersPlayback) {
-                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::ChannelNameReadable[vols.first().chid]+")");
+                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::ChannelNameReadable[vols.first().chid]+')');
                         vols.pop_front();
                 }
                 vols = m_mixdevice->captureVolume().getVolumes().values();
                 foreach (QAbstractSlider *slider, m_slidersCapture) {
-                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::ChannelNameReadable[vols.first().chid]+")");
+                        slider->setAccessibleName(slider->toolTip()+ " (" +Volume::ChannelNameReadable[vols.first().chid]+')');
                         vols.pop_front();
                 }
         }
@@ -1168,8 +1157,8 @@ void MDWSlider::showContextMenu( const QPoint& pos )
 	if( m_view == 0 )
 		return;
 
-	KMenu *menu = m_view->getPopup();
-	menu->addTitle( SmallIcon( "kmix" ), m_mixdevice->readableName() );
+	QMenu *menu = m_view->getPopup();
+	menu->addSection( SmallIcon( "kmix" ), m_mixdevice->readableName() );
 
 	if (m_moveMenu) {
 		MixSet *ms = m_mixdevice->getMoveDestinationMixSet();
@@ -1228,13 +1217,13 @@ void MDWSlider::showMoveMenu()
     m_moveMenu->clear();
 
     // Default
-    KAction *a = new KAction(_mdwMoveActions);
+    QAction *a = new QAction(_mdwMoveActions);
     a->setText( i18n("Automatic According to Category") );
     _mdwMoveActions->addAction( QString("moveautomatic"), a);
     connect(a, SIGNAL(triggered(bool)), SLOT(moveStreamAutomatic()), Qt::QueuedConnection);
     m_moveMenu->addAction( a );
 
-    a = new KAction(_mdwMoveActions);
+    a = new QAction(_mdwMoveActions);
     a->setSeparator(true);
     _mdwMoveActions->addAction( QString("-"), a);
 
@@ -1280,13 +1269,13 @@ bool MDWSlider::eventFilter( QObject* obj, QEvent* e )
 		QAbstractSlider *slider = qobject_cast<QAbstractSlider*>(obj);
 		if (slider != 0)
 		{
-//			kDebug();
-//			kDebug();
-//			kDebug() << "----------------------------- Slider is " << slider;
+//			qCDebug(KMIX_LOG);
+//			qCDebug(KMIX_LOG);
+//			qCDebug(KMIX_LOG) << "----------------------------- Slider is " << slider;
 			// Mouse is over a slider. So lets apply the wheel event to playback or capture only
 			if(m_slidersCapture.contains(slider))
 			{
-//				kDebug() << "Slider is capture " << slider;
+//				qCDebug(KMIX_LOG) << "Slider is capture " << slider;
 				volumeType = Volume::Capture;
 			}
 		}
@@ -1306,9 +1295,9 @@ bool MDWSlider::eventFilter( QObject* obj, QEvent* e )
 		if (slider != 0)
 		{
 			Volume& volP = m_mixdevice->playbackVolume();
-//			kDebug() << "slider=" << slider->objectName();
+//			qCDebug(KMIX_LOG) << "slider=" << slider->objectName();
 			VolumeSliderExtraData& sliderExtraData = extraData(slider);
-//			kDebug() << "slider=" << slider->objectName() << "sliderExtraData=" << sliderExtraData.getSubcontrolLabel() << " , chid=" << sliderExtraData.getChid();
+//			qCDebug(KMIX_LOG) << "slider=" << slider->objectName() << "sliderExtraData=" << sliderExtraData.getSubcontrolLabel() << " , chid=" << sliderExtraData.getChid();
 			volumeValues.push_back(volP.getVolume(sliderExtraData.getChid()));
 		}
 		return true;
